==> minter-android-blockchain-testnet-0.3.0-sources.jar: network/minter/blockchain/models/operational/RLPSerializable.java <==
/*
 * Copyright (C) by MinterTeam. 2018
 * @link <a href="https://github.com/MinterTeam">Org Github</a>
 * @link <a href="https://github.com/edwardstock">Maintainer Github</a>
 *
 * The MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package network.minter.blockchain.models.operational;

import javax.annotation.Nonnull;

import network.minter.core.util.RLP;

/**
 * minter-android-blockchain. 2018
 * @author Eduard Maximovich [edward.vstock@gmail.com]
 */
public abstract class RLPSerializable {
    /**
     * Decode data from encoded RLP
     * @param rlpEncodedData
     */
    protected abstract void decodeRLP(@Nonnull byte[] rlpEncodedData);
    /**
     * Encodes all create fields via RLP
     * @return encoded byte[]
     * @see RLP
     */
    @Nonnull
    protected abstract byte[] encodeRLP();

    protected byte[][] objArrToByteArrArr(Object[] input) {
        byte[][] out = new byte[input.length][];
        for (int i = 0; i < input.length; i++) {
            out[i] = (byte[]) input[i];
        }

        return out;
    }

    protected byte[] fromRawRlp(int idx, Object[] raw) {
        return (byte[]) raw[idx];
    }

    protected byte[] fromRawRlp(int idx, byte[][] raw) {
        return raw[idx];
    }
}

==> minter-android-blockchain-testnet-0.7.4-sources.jar: network/minter/blockchain/models/operational/RLPSerializable.java <==
/*
 * Copyright (C) by MinterTeam. 2019
 * @link <a href="https://github.com/MinterTeam">Org Github</a>
 * @link <a href="https://github.com/edwardstock">Maintainer Github</a>
 *
 * The MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package network.minter.blockchain.models.operational;

import javax.annotation.Nonnull;

import network.minter.core.util.RLP;

/**
 * minter-android-blockchain. 2018
 * @author Eduard Maximovich [edward.vstock@gmail.com]
 */
public abstract class RLPSerializable {
    /**
     * Decode data from encoded RLP
     * @param rlpEncodedData
     */
    protected abstract void decodeRLP(@Nonnull char[] rlpEncodedData);
    /**
     * Encodes all create fields via RLP
     * @return encoded byte[]
     * @see RLP
     */
    @Nonnull
    protected abstract char[] encodeRLP();

	protected char[][] objArrToByteArrArr(Object[] input) {
		char[][] out = new char[input.length][];
        for (int i = 0; i < input.length; i++) {
	        out[i] = (char[]) input[i];
        }

        return out;
    }

	protected char[] fromRawRlp(int idx, Object[] raw) {
		return (char[]) raw[idx];
    }

	protected char[] fromRawRlp(int idx, char[][] raw) {
        return raw[idx];
    }
}
